=======
History
=======

0.x.x (coming soon)
-------------------

New features:
*

Bugfixes:
*


0.14.5 (2020-09-23)
-------------------

New features:
* Additional tables for multispectral mode are now downloaded during pip install.

Bugfixes:
* Moved imports of scikit-image from module level to function level to avoid
  'ImportError: dlopen: cannot load any more object with static TLS'.
* Fixed DeprecationWarnings h), i), and j) from issue #53.


0.14.4 (2020-09-07)
-------------------

New features:
* AC LUT is now downloaded during setup.py.

Bugfixes:
* Fixed issue #62 (ecmwf-api-client ImportError after following the installation instructions for the hyperspectral
  part of SICOR).


0.14.3 (2020-09-02)
-------------------
New features:
* The package is now available on the Python Package Index.
* Added 'deploy_pypi' CI job.


0.14.2 (2020-05-14)
-------------------
New features:
* Segmentation of input radiance data cubes to enhance processing speed
* Empirical line solution for extrapolating reflectance spectra based on segment averages


0.14.1 (2019-02-18)
-------------------
New features:
* Optimal estimation for atmospheric and surface parameters
* Calculation of retrieval uncertainties


0.14.0 (2019-02-11)
-------------------
New features:
* New EnMAP atmospheric correction
* 3 phases of water retrieval for hyperspectral data


0.13.0 (2018-12-18)
-------------------

* Development by Niklas Bohn started.
